# Needed when building new python3 version
%bcond_with bootstrap

# hardcoded so that build from another distro keeps this name
# (mandatory to have correct package name and source name)
%define _real_vendor mageia

# fix build (debuginfo package is empty...):
%define debug_package %{nil}

# If dist tag isn't defined, define it
%if %{?dist:0}%{?!dist:1}
%define dist %{?distsuffix:%distsuffix}%{?!distsuffix:.mga}%{?distro_release:%distro_release}
%endif

# If mkrel isn't defined, define it
%if %{?mkrel:0}%{?!mkrel:1}
%define mkrel(c:) %{-c: 0.%{-c*}.}%{1}%{?dist:%dist}%{?subrel:.%subrel}
%endif

# This can be useful for backport, as rpm-4.2
# provides the emacs-spec mode
%define have_emacsmodespec 1

%{?_with_emacsspecmode: %define have_emacsmodespec 1}
%{?_without_emacsspecmode: %define have_emacsmodespec 0}

%ifarch %{ix86}
%global _host_cpu %_target_cpu
%endif
%ifarch armv7hl
%global _host_cpu armv7hl
%endif

Summary:	The %{distribution} rpm configuration and scripts
Name:		rpm-%{_real_vendor}-setup
Version:	2.83
Release:	%mkrel 4
# No patch allowed on SOURCE0
# prevent suse script to slow down build:
Patch0:		gi-find-deps.sh.diff
# (tv) "handle" golang style templates in py files in gnome-builder-42.1
# resource files, which resulted in "typelib(Adw{{end}})" deps:
Patch1:		gi-find-deps.sh2.diff
Patch11:	gi-find-deps-grep-E.patch
# fix Suse attr matching:
Patch2:		gobjectintrospection.attr.patch
Patch3:		gobjectintrospection.attr2.patch
# handle filenames with space (mga#29941)
Patch4:		gi-find-deps-handle-filenames-with-space.patch
# make sure %%perl_convert_version macro is used with perl provides and requires generation
Patch5:		use_perl_convert_version.diff
# make gi-find-deps to also work with new GIRepository 3.0
Patch6:		gi-find-deps-GIRepository3.0.patch

Source0:	%{name}-%{version}.tar.xz
Source1:	gettarball.sh
#
# UPSTREAM TO SYNC:
#
# gi-find-deps.sh is a rpm helper for Provides and Requires. Script creates typelib()-style Provides/Requires.
# (From: https://build.opensuse.org/package/show/openSUSE:Factory/gobject-introspection)
Source3:        gi-find-deps.sh
Source4:        gobjectintrospection.attr
#
# Fedora stuff:
#
# kernel modules provides/requires
# (Was from redhat-rpm-config, now: kernel-srpm-macros)
Source5:        kmod.attr
Source6:        kmod.prov
# Forge handling macros
# (From: https://src.fedoraproject.org/rpms/redhat-rpm-config/tree):
# The macros defined by these files are for things that need to be defined
# at srpm creation time when it is not feasible to require the base packages
# that would otherwise be providing the macros. other language/arch specific
# macros should not be defined here but instead in the base packages that can
# be pulled in at rpm build time, this is specific for srpm creation.
Source102:	macros.mono-srpm
Source105:	macros.valgrind-srpm
Source106:      macros.java-srpm

# ldconfig stub macros for compatibility
# (From: https://src.fedoraproject.org/rpms/redhat-rpm-config/tree):
# Other misc macros
Source150:	macros.build-constraints
Source151:	macros.dwz
Source152:	macros.fedora-misc
Source153:      macros.forge
Source155:      macros.ldconfig

Source156:	macros.vpath

# Misc helper scripts
Source404:	gpgverify

# Convenience lua functions
Source800:       common.lua
Source801:       forge.lua

# Dropped from rpm upstream,
# New upstream https://github.com/rpm-software-management/perl-rpm-packaging/
# Use script version without 'normalized version support'
Source810:	https://raw.githubusercontent.com/rpm-software-management/perl-rpm-packaging/b534fc7ca37b6e81797a1fe47a99b2b7af860b5a/scripts/perl.prov
Source811:	https://raw.githubusercontent.com/rpm-software-management/perl-rpm-packaging/b534fc7ca37b6e81797a1fe47a99b2b7af860b5a/scripts/perl.req
# These were also dropped from rpm
Source812:	https://raw.githubusercontent.com/rpm-software-management/perl-rpm-packaging/d9ba508177d0841d48af8702aeedeb3295d29611/fileattrs/perl.attr
Source813:	https://raw.githubusercontent.com/rpm-software-management/perl-rpm-packaging/d9ba508177d0841d48af8702aeedeb3295d29611/fileattrs/perllib.attr

#
# END OF UPSTREAM
#

# NO PATCH ACCEPTED: WORK in GIT!!!!
License:	GPLv2+
Group:		System/Packaging
Url:		https://www.mageia.org/
# rpm-devel provide doesn't include epoch
BuildRequires:	rpm-devel >= 4.19.91
BuildRequires:	automake

%description
The %{distribution} rpm configuration and scripts.

%package	build
Group:		System/Packaging
Summary:	The %{distribution} rpm configuration and scripts to build rpms
Requires:	rpm-build >= 1:4.19.91
Requires:	spec-helper
Requires:	multiarch-utils
# needed for script to extract pkgconfig info
Requires:	pkgconfig
Requires:	%name = %version-%release
Requires:	bash >= 4.3-24.2
# gi-find-deps uses the enhanced grep variant in order to do
# multi-line matching (for pkg.requires(..))
Requires:	pcre2-tools
# gi-find-deps makes use of 'file' to identify the types.
Requires:	file
# for product version macros
Requires:	%{_real_vendor}-release
Requires:	dwz
# to generate cmake() provides
Requires:	cmake-rpm-macros >= 1:9-8
Requires:	efi-srpm-macros
Requires:	fonts-srpm-macros
Requires:	go-srpm-macros
Requires:	lua-srpm-macros
Requires:	ocaml-srpm-macros
Requires:	perl-srpm-macros
# ↓ Provides compileall2 Python module and brp-python-bytecompile scriptlet
Requires:	python-srpm-macros >= 3.10-4
Requires:	pyproject-rpm-macros
# rust-srpm-macros v24 contains %%build_rustflags defintion
Requires:	rust-srpm-macros >= 24

# for gdb-add-index:
Requires:	gdb-headless
%if ! %{with bootstrap}
# for g-ir-dep-tool:
Requires:	gobject-introspection
# python packaging
Requires:	python3-pkg-resources
%endif
# For gi-inspect-typelib used in gi-find-deps
Requires:	glib2.0-common
Requires:	desktop-file-utils
# This is not needed in the buildsystem but desirable for local development
Recommends:	rpmlint-mageia-policy
# Provide generic name for rpm vendor configuration
Provides:	system-rpm-config = %{version}-%{release}
# Due to perl.{prov,req} move (mga#33377)
Conflicts:	rpm-build < 1:4.20.0-1

%description	build
The %{distribution} rpm configuration and scripts dedicated to build rpms.

%prep
%setup -q
install -Dp %{S:3} .
install -Dp %{S:4} .
install -Dp %{S:810} %{S:811} %{S:812} %{S:813} .

%autopatch -p1

%build
autoreconf -fi
%configure || tail -1000 config.log
%make_build

%install
%make_install

# install latest config.{guess,sub} provided by automake
for i in config.{guess,sub}; do
  install -Dpm755 %{_datadir}/automake-*/$i %{buildroot}%{_rpmconfigdir}/%{_real_vendor}/
done

# upstream deps generators:
install -D gi-find-deps.sh %{S:6} -m 0755 %{buildroot}%{_rpmconfigdir}/
install -D gobjectintrospection.attr %{S:5} -m 0644 %{buildroot}%{_rpmconfigdir}/fileattrs/

install -D perl.prov perl.req -m 0755 %{buildroot}%{_rpmconfigdir}/
install -D perl.attr perllib.attr -m 0644 %{buildroot}%{_rpmconfigdir}/fileattrs/

mkdir -p %{buildroot}%{_rpmconfigdir}/macros.d
install -D %{S:102} %{S:105} %{S:106} %{S:150} %{S:151} %{S:152} %{S:153} %{S:155} %{S:156} -m 0644 %{buildroot}%{_rpmconfigdir}/macros.d/

install -D %{S:404} %{buildroot}%{_rpmconfigdir}/redhat/gpgverify

mkdir -p %{buildroot}%{_rpmluadir}/fedora/{rpm,srpm}
install -D %{S:800} %{buildroot}%{_rpmluadir}/fedora
install -D %{S:801} %{buildroot}%{_rpmluadir}/fedora/srpm

%if %have_emacsmodespec
# spec mode for emacs
install -d $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/
install -m644 rpm-spec-mode.el $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/

install -d $RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d
cat <<EOF >$RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d/%{name}.el
(setq auto-mode-alist (cons '("\\\\.spec$" . rpm-spec-mode) auto-mode-alist))
(autoload 'rpm-spec-mode "rpm-spec-mode" "RPM spec mode (for %{distribution})." t)
EOF
%endif

%check
make test

%files
%dir %{_rpmconfigdir}/%{_real_vendor}
%{_rpmconfigdir}/%{_real_vendor}/macros
%{_rpmconfigdir}/%{_real_vendor}/rpmrc

%files build
%doc NEWS
%{_rpmconfigdir}/%{_real_vendor}/config.{guess,sub}
%{_rpmconfigdir}/%{_real_vendor}/*.{req,prov}
%{_rpmconfigdir}/%{_real_vendor}/drop-ld-no-undefined-for-shared-lib-modules-in-libtool
%{_rpmconfigdir}/%{_real_vendor}/find-provides
%{_rpmconfigdir}/%{_real_vendor}/find-requires
%{_rpmconfigdir}/%{_real_vendor}/fix-dlsearch-path-in-libtool-for-multilib
%{_rpmconfigdir}/%{_real_vendor}/fix-libtool-from-moving-options-after-libs
%{_rpmconfigdir}/%{_real_vendor}/fix-libtool-ltmain-from-overlinking
%{_rpmconfigdir}/%{_real_vendor}/force-as-needed-for-shared-lib-in-libtool
%{_rpmconfigdir}/%{_real_vendor}/perl.req-from-meta
%{_rpmconfigdir}/%{_real_vendor}/perl.recommends-from-meta
%{_rpmconfigdir}/%{_real_vendor}/platform/
%{_rpmconfigdir}/gi-find-deps.sh
%{_rpmconfigdir}/macros.d/*
%{_rpmconfigdir}/*.{prov,req}
%{_rpmluadir}/fedora/
%{_rpmconfigdir}/redhat/*
%exclude %{_rpmconfigdir}/%{_real_vendor}/rpmrc
%if %have_emacsmodespec
%{_datadir}/emacs/site-lisp/rpm-spec-mode.el
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/%{name}.el
%endif
%{_rpmconfigdir}/fileattrs/*.attr


%changelog
* Sat Mar 22 2025 wally <wally> 2.83-4.mga10
+ Revision: 2169038
- patch gi-find-deps.sh to output reqs also for GIRepository 3.0 typelibs

* Fri Feb 21 2025 wally <wally> 2.83-3.mga10
+ Revision: 2150497
- non-bootstrap build for python3.13

* Wed Feb 19 2025 neoclust <neoclust> 2.83-2.mga10
+ Revision: 2149793
- Rebuild in bootstrap mode

* Sat Jan 25 2025 wally <wally> 2.83-1.mga10
+ Revision: 2142153
- new version 2.83
  * generate recommends from perl META (mga#33945)

* Sat Dec 28 2024 wally <wally> 2.82-1.mga10
+ Revision: 2130830
- new version 2.82
  - macros: automatically use %%set_build_flags macro for build, check, and install phases
  - brp-mangle-shebangs: restore handling of %%__brp_mangle_shebangs_exclude

* Mon Nov 11 2024 wally <wally> 2.81-1.mga10
+ Revision: 2114301
- new version 2.81

* Sat Oct 19 2024 wally <wally> 2.80-7.mga10
+ Revision: 2108250
- fix perl reqs and provides generator to use %%perl_convert_version again

* Tue Oct 15 2024 wally <wally> 2.80-6.mga10
+ Revision: 2107056
- rebuild for fixed rpm-mageia-setup 2.80-5 :D

* Tue Oct 15 2024 wally <wally> 2.80-5.mga10
+ Revision: 2107044
- provide perl attr files removed from rpm >= 4.20.0

* Tue Jul 16 2024 wally <wally> 2.80-4.mga10
+ Revision: 2081750
- rebuild with latest perl.{prov,req}

* Tue Jul 16 2024 wally <wally> 2.80-3.mga10
+ Revision: 2081745
- use perl.{prov,req} script version without normalized version support for now
- add perl.prov and perl.req from new upstream as they were dropped from rpm itself (mga#33377)

* Fri Jul 05 2024 wally <wally> 2.80-2.mga10
+ Revision: 2079868
- tighten rpm requires

* Fri Jul 05 2024 wally <wally> 2.80-1.mga10
+ Revision: 2079861
- new version 2.80

* Sun Apr 21 2024 wally <wally> 2.79.1-1.mga10
+ Revision: 2060272
- new version 2.79.1
  - add and enable %%_hardened_build (from Fedora) to build pkgs with position-independent code by default

* Thu Apr 11 2024 wally <wally> 2.78-1.mga10
+ Revision: 2056589
- new version 2.78
  - use -D_FORTIFY_SOURCE=3 by default (mga#30920)

* Tue Apr 02 2024 wally <wally> 2.77-1.mga10
+ Revision: 2054006
- new version 2.77 for i686 support

* Sun Mar 31 2024 wally <wally> 2.76.1-1.mga10
+ Revision: 2053499
- new version 2.76.1
  - rpmrc: don't use -fstack-clash-protection on aarch64 with the clang toolchain

* Sat Mar 30 2024 wally <wally> 2.76-1.mga10
+ Revision: 2053249
- new version 2.76
  - macros: add support for toolchain selection (GCC/Clang)

* Sun Mar 24 2024 wally <wally> 2.75.1-1.mga10
+ Revision: 2051681
- new version 2.75.1

* Sat Mar 02 2024 wally <wally> 2.74.2-2.mga10
+ Revision: 2046660
- tune armv7 default optflags

* Thu Feb 29 2024 wally <wally> 2.74.2-1.mga10
+ Revision: 2045903
- new version 2.74.2

* Wed Feb 28 2024 wally <wally> 2.74.1-6.mga10
+ Revision: 2045399
- force correct %%_host_cpu

* Wed Feb 28 2024 wally <wally> 2.74.1-5.mga10
+ Revision: 2045298
- rebuild for arm32

* Wed Feb 28 2024 wally <wally> 2.74.1-4.mga10
+ Revision: 2045046
- rebuild to debug armv7hl failures

* Wed Feb 28 2024 wally <wally> 2.74.1-3.mga10
+ Revision: 2045041
- try to fix armv7hl target cpu another way

* Wed Feb 28 2024 wally <wally> 2.74.1-2.mga10
+ Revision: 2044862
- fix armv7hl target cpu

* Tue Feb 27 2024 wally <wally> 2.74.1-1.mga10
+ Revision: 2044729
- new version 2.74.1

* Fri Dec 08 2023 daviddavid <daviddavid> 2.73-7.mga10
+ Revision: 2015586
- rebuild also for py3.12

* Fri Dec 08 2023 daviddavid <daviddavid> 2.73-6.mga10
+ Revision: 2015549
- sync gi-find-deps.sh script with opensuse one:
  * fixes our current broken typelib()-style Provides/Requires (mga#32553)
  * script was ported to pcre2

* Thu Dec 07 2023 wally <wally> 2.73-5.mga10
+ Revision: 2014952
- non-bootstrap build for py3.12 update

* Thu Dec 07 2023 wally <wally> 2.73-4.mga10
+ Revision: 2014736
- pyproject-rpm-macros can be pulled in bootstrap mode

* Thu Dec 07 2023 wally <wally> 2.73-3.mga10
+ Revision: 2014449
- don't require pyproject-rpm-macros while bootstrapping

* Thu Dec 07 2023 wally <wally> 2.73-2.mga10
+ Revision: 2014392
- bootstrap build for py3.12 update

* Wed Nov 22 2023 wally <wally> 2.73-1.mga10
+ Revision: 2009227
- new version 2.73
- require pyproject-rpm-macros

* Sat Nov 18 2023 wally <wally> 2.72-1.mga10
+ Revision: 2007450
- new version 2.72
  - macros: define _use_weak_usergroup_deps to only add user() and group() requires as recommends

* Sat Sep 30 2023 tv <tv> 2.71-2.mga10
+ Revision: 1992569
- Add macros.build-constraints from FC in order to constrain huge builds

* Sun Jan 15 2023 wally <wally> 2.71-1.mga9
+ Revision: 1933353
- new version 2.71
  - brp-mangle-shebangs: also mangle shebangs of JavaScript executables (rhbz#1998924)
  - macros: drop unused %%_sys_macros_dir and %%build_sysmacrospath()

* Sat Jan 14 2023 wally <wally> 2.70-3.mga9
+ Revision: 1932929
- bump cmake-rpm-macros reqs

* Sat Jan 07 2023 wally <wally> 2.70-2.mga9
+ Revision: 1931021
- stop shipping and owning /etc/rpm/macros.d/

* Sat Jan 07 2023 wally <wally> 2.70-1.mga9
+ Revision: 1930956
- new version 2.70
  - drop separate macros.build

* Sat Jan 07 2023 wally <wally> 2.69-2.mga9
+ Revision: 1930936
- install macros.build to /etc/rpm/macros.d/ as build.macros to not get overriden by platform macros

* Sat Jan 07 2023 wally <wally> 2.69-1.mga9
+ Revision: 1930905
- new version 2.69
  - fix macros.build in sources
  - add macros.gnome
  - fix rpm-spec-mode.el compatibility with emacs >= 28.1

* Sat Sep 03 2022 wally <wally> 2.67-1.mga9
+ Revision: 1883681
- new version 2.67 to replace egrep with 'grep -E' in scriptlets

* Mon Jul 25 2022 tv <tv> 2.66-3.mga9
+ Revision: 1871412
- Define %%java_arches for the java stack

* Thu Jul 14 2022 wally <wally> 2.66-2.mga9
+ Revision: 1868917
- fix perl invocation introduced in r1863965 in gi-find-deps.sh to avoid tons of '-i used with no filenames on the command line, reading from STDIN.' entries in build logs

* Sun Jun 19 2022 wally <wally> 2.66-1.mga9
+ Revision: 1865183
- new version 2.66
  - use -Wl,--build-id=sha1 in %%build_ldflags
+ tv <tv>
- Revert "fix" now that bogus file-5.42 has been reverted to 5.41

* Sat Jun 11 2022 tv <tv> 2.65-2.mga9
+ Revision: 1863969
- Disable brp_mangle_shebangs as it failed on BS whereas it works locally
- "handle" golang style templates in py files in gnome-builder-42.1
  resource files, which resulted in "typelib(Adw{{end}})" deps

* Sun Apr 10 2022 wally <wally> 2.65-1.mga9
+ Revision: 1848654
- new version 2.65
- remove mdv leftover provides

* Sun Apr 10 2022 wally <wally> 2.63-2.mga9
+ Revision: 1848627
- update python-srpm-macros requires

* Sun Apr 10 2022 wally <wally> 2.63-1.mga9
+ Revision: 1848620
- new version 2.63 without brp-python-bytecompile living nowadays in python-rpm-macros

* Wed Mar 23 2022 umeabot <umeabot> 2.62-5.mga9
+ Revision: 1821246
- Mageia 9 Mass Rebuild

* Sun Feb 06 2022 wally <wally> 2.62-4.mga9
+ Revision: 1772035
- disable bootstrap build

* Sat Feb 05 2022 wally <wally> 2.62-3.mga9
+ Revision: 1771568
- bootstrap build for upcoming python3.10 update

* Thu Jan 27 2022 wally <wally> 2.62-2.mga9
+ Revision: 1770019
- gi-find-deps.sh: add patch to handle files with spaces in their names more properly (mga#29941)

* Sun Oct 17 2021 wally <wally> 2.62-1.mga9
+ Revision: 1751953
- new version 2.62
  - build.macros: export LT_SYS_LIBRARY_PATH with %%set_build_flags to prevent
    libtool hardcoding %%_libdir into the binaries' RPATH (originally from Fedora)

* Tue Sep 07 2021 wally <wally> 2.61-1.mga9
+ Revision: 1744415
- new version 2.61
  - brp-mangle-shebang: fix handling of files without newlines (from Fedora)
  - build.macros: run /usr/lib/rpm/brp-remove-la-files after %%install (available since RPM 4.17.0)
  - build.macros: run /usr/lib/rpm/check-rpaths after %%install

* Wed Jun 23 2021 tv <tv> 2.60-1.mga9
+ Revision: 1731810
- Drop __brp_python_hardlink for rpm-4.17beta1
- Temporary ship brp-python-bytecompile as part of rpm-mageia-setup for now
  At some point though we'll want to package:
  https://github.com/rpm-software-management/python-rpm-packaging/

* Tue Jun 01 2021 tv <tv> 2.59-1.mga9
+ Revision: 1729161
- Drop __brp_strip_shared for rpm-4.17

* Thu May 13 2021 tv <tv> 2.58-5.mga9
+ Revision: 1722708
- Pull in efi-srpm-macros

* Sun Mar 28 2021 wally <wally> 2.58-4.mga9
+ Revision: 1711497
- require lua-srpm-macros with rpm-mageia-setup-build

* Sun Mar 14 2021 wally <wally> 2.58-3.mga9
+ Revision: 1702624
- disable bootstrap build

* Sun Mar 14 2021 wally <wally> 2.58-2.mga9
+ Revision: 1702506
- bootstrap build for new python 3.9

* Sat Mar 13 2021 wally <wally> 2.58-1.mga9
+ Revision: 1701951
- set %%_python_bytecompile_extra to 0
- update rpm-spec-mode.el to version 0.16

* Mon Aug 17 2020 wally <wally> 2.57-2.mga8
+ Revision: 1614614
- install config.{guess,sub} with execute rights

* Tue Jun 23 2020 tv <tv> 2.57-1.mga8
+ Revision: 1598615
- %%rename:
  o don't obsolete what is provided (mga#26801)
  o take a 2nd arg to set the VR to obsolete

* Thu Jun 04 2020 ngompa <ngompa> 2.56-2.mga8
+ Revision: 1590386
- Downgrade rpmlint-mageia-policy dependency to Recommends as it's not needed in buildsystem
- Add comment to indicate purpose of system-rpm-config Provides

* Mon Jun 01 2020 wally <wally> 2.56-1.mga8
+ Revision: 1589611
- build.macros: add _configure_gnuconfig_hack macro based on one from Fedora to update config.{guess,sub}

* Mon Jun 01 2020 wally <wally> 2.55-2.mga8
+ Revision: 1589495
- install config.{guess,sub} from autotools to /usr/lib/rpm/mageia as rpm itself dropped them

* Thu May 21 2020 wally <wally> 2.55-1.mga8
+ Revision: 1586624
- build macros: add _legacy_common_support macro for conditionally adding -fcommon to compiler flags,
  add '%%define _legacy_common_support 1' to .spec to use it
- build.macros: run /usr/lib/rpm/check-buildroot at end of %%install scriptlet
  via __arch_install_post
+ tv <tv>
- remove 5 & 6 years old conflicts
- Add virtual system-rpm-config provide

* Tue Apr 14 2020 tv <tv> 2.54-1.mga8
+ Revision: 1567280
- stop emiting requires(posttrans) on info-install (less container bloat)

* Mon Apr 06 2020 ovitters <ovitters> 2.53-4.mga8
+ Revision: 1565121
- add require on fonts-srpm-macros in setup subpackage (new Fedora font packaging macros)

* Wed Mar 11 2020 tv <tv> 2.53-3.mga8
+ Revision: 1555491
- include gpgverify from FC so that %%{gpgverify} works

* Thu Feb 20 2020 umeabot <umeabot> 2.53-2.mga8
+ Revision: 1546954
- Mageia 8 Mass Rebuild

* Wed Feb 12 2020 tv <tv> 2.53-1.mga8
+ Revision: 1506701
- build.macros: restore '--without <section>' rpmbuild functionality
  (which is very useful in order to work on huge packages before submiting them
  to BS)

* Wed Feb 05 2020 wally <wally> 2.52-1.mga8
+ Revision: 1487304
- new version 2.52
  - build.macros: remove '--without <section>' rpmbuild functionality
  - build.macros: add __spec_install_post

* Mon Feb 03 2020 wally <wally> 2.51-1.mga8
+ Revision: 1486672
- new version 2.51
  - use %%_ssp_cflags also with arm %%optflags
  - drop unused macros
    - _package_i18n()
    - _with()
    - _without()
    - py_platlibdir
    - py_purelibdir
    - py_platsitedir
    - py_puresitedir
    - perl_sitearch
    - perl_archlib
- replace deprecated %%configure2_5x

* Thu Jan 16 2020 wally <wally> 2.50-1.mga8
+ Revision: 1478220
- replace %%configure2_5x with %%configure synced with rpm upstream and without legacy libtoolize
- keep %%configure2_5x macro available for compatibility

* Thu Jan 02 2020 wally <wally> 2.48-1.mga8
+ Revision: 1475490
- new version 2.48
- don't ship build macros twice

* Thu Dec 26 2019 wally <wally> 2.47-1.mga8
+ Revision: 1470109
- replace %%setup_compile_flags with upstream %%set_build_flags and
  output deprecation warning if %%setup_compile_flags is used

* Wed Dec 25 2019 wally <wally> 2.46-3.mga8
+ Revision: 1470053
- introduce macros.vpath for %%_vpath_srcdir and %%_vpath_builddir to be used with cmake/meson/ninja/etc

* Wed Dec 25 2019 wally <wally> 2.46-2.mga8
+ Revision: 1470049
- sync gi-find-deps.sh with openSUSE

* Tue Dec 24 2019 wally <wally> 2.46-1.mga8
+ Revision: 1469860
- brp-mangle-shebangs: do not exit if read has a non-zero status

* Mon Dec 23 2019 tv <tv> 2.45-1.mga8
+ Revision: 1469722
- switch binary payload compression to Zstandard level 19
  for faster installations
  See https://fedoraproject.org/wiki/Changes/Switch_RPMs_to_zstd_compression
- sync brp-mangle-shebangs with FC:
  o do not stat / touch files needlessly
  o fix unsafe/incorrect command expansion
  o brp-mangle-shebangs: speed up finding of "text executables" (scripts)
  o Make ambiguous python shebangs error

* Wed Dec 18 2019 guillomovitch <guillomovitch> 2.44-3.mga8
+ Revision: 1468823
- add missing macros.fedora-misc file

* Wed Dec 18 2019 guillomovitch <guillomovitch> 2.44-2.mga8
+ Revision: 1468818
- sync lua macros with fedora

* Tue Oct 15 2019 pterjan <pterjan> 2.44-1.mga8
+ Revision: 1453908
- Try harder.

* Tue Oct 15 2019 pterjan <pterjan> 2.43-1.mga8
+ Revision: 1453880
- Fix more armv7hl chroots on aarch64

* Tue Oct 15 2019 pterjan <pterjan> 2.42-1.mga8
+ Revision: 1453867
- Fix armv7hl chroots on aarch64

* Thu Sep 19 2019 tv <tv> 2.41-1.mga8
+ Revision: 1443807
- bump rel for core/updates_testing

* Wed Sep 04 2019 wally <wally> 2.40-8.mga8
+ Revision: 1436932
- non-bootstrap build for python3.8

* Wed Sep 04 2019 tv <tv> 2.40-7.mga8
+ Revision: 1436906
- bump rel for core/updates_testing

* Wed Sep 04 2019 tv <tv> 2.40-6.mga8
+ Revision: 1436890
- bootstrap build again for python3.8

* Wed Sep 04 2019 tv <tv> 2.40-5.mga8
+ Revision: 1436873
- requires perl-srpm-macros for macros droped by rpm-4.15
+ wally <wally>
- non-bootstrap build for python3.8

* Tue Sep 03 2019 wally <wally> 2.40-3.mga8
+ Revision: 1436681
- bootstrap build for python3.8

* Fri Aug 30 2019 tv <tv> 2.40-2.mga8
+ Revision: 1435205
- concat macros.build into vendor macros thus fixing %%__os_install_post not
  being overidden

* Thu Aug 29 2019 tv <tv> 2.40-1.mga8
+ Revision: 1435176
- move files from /etc/rpm/macros.d into /usr/lib/rpm/macros.d thus fixing most
  issues with rpm's testsuite (related to not being able to disable debuginfo)

* Fri Jul 19 2019 ngompa <ngompa> 2.39-2.mga8
+ Revision: 1422833
- Add ldconfig macros from Fedora for compatibility that do nothing

* Sat May 04 2019 pterjan <pterjan> 2.39-1.mga7
+ Revision: 1396356
- Fix armv7hl chroots on aarch64 hardware

* Mon Mar 11 2019 tv <tv> 2.38-1.mga7
+ Revision: 1374117
- add %%_metainfodir macro for appdata metainfo dir
- kill ldd path code in devel.req (unused for 12 years)
- php.req:
  o don't a cache file that we never read back, thus fixing emited deps
  o use Find::File in order to find files
  Note that our macros.forge starts to be old against FC origin...

* Sat Jan 05 2019 wally <wally> 2.37-9.mga7
+ Revision: 1349489
- disable bootstrap

* Fri Jan 04 2019 wally <wally> 2.37-8.mga7
+ Revision: 1349064
- add and enable bootstrap switch for python3 major version updates

* Thu Nov 22 2018 pterjan <pterjan> 2.37-7.mga7
+ Revision: 1333093
- Update fedora forge macros

* Wed Nov 21 2018 pterjan <pterjan> 2.37-6.mga7
+ Revision: 1332575
- Fix forgemeta adding twice the date+hash to dist when main package is noarch
- Revert commit on wrogn branch
- Drop requires not existing on mageia 6

* Mon Nov 19 2018 pterjan <pterjan> 2.37-5.mga7
+ Revision: 1331489
- Have -build require go-srpm-macros to be able to recreate src.rpm using gometa

* Sun Nov 18 2018 pterjan <pterjan> 2.37-4.mga7
+ Revision: 1331284
- Install the files...
- Add macros to manage things from forges from Fedora

* Sat Oct 27 2018 wally <wally> 2.37-2.mga7
+ Revision: 1326230
- sync gi-find-deps.sh with suse
  - support new Polari's imports.gi pattern 'const { Foo, Bar } = imports.gi;'

* Sun Oct 21 2018 wally <wally> 2.37-1.mga7
+ Revision: 1323212
- Strip binaries and libraries in __os_install_post when debug pkgs aren't built
  * stripping can be disabled with '%%define __strip %%{_bindir}/true'

* Mon Sep 24 2018 tv <tv> 2.36-1.mga7
+ Revision: 1303444
- add __brp_mangle_shebangs in order to fix /bin -> /usr/bin & "env foobar"
- automatically compile python files

* Mon Sep 24 2018 tv <tv> 2.35-2.mga7
+ Revision: 1303410
- bump release

* Mon Sep 24 2018 tv <tv> 2.35-1.mga7
+ Revision: 1303409
- reduce triming changelog from 3 to 2 years
- remove duplicated systemd macros
- sync %%__brp_python_bytecompile with upstream :
  o "%%global __python %%{__python3}" enables to properly fix py3 bytecompiling
  o also recognize %%_python_bytecompile_extra for compiling outisde python
    specific directories
- terminate build when missing buildids by default

* Sat Sep 08 2018 tv <tv> 2.34-1.mga7
+ Revision: 1257760
- emits requires(posttrans) on info-install
  (needs newer rpm)

* Fri Sep 07 2018 tv <tv> 2.33-1.mga7
+ Revision: 1257727
- emits requires on info-install instead of provides for *.info files

* Tue Sep 04 2018 tv <tv> 2.32-1.mga7
+ Revision: 1256938
- automatically emits requires on info-install for *.info files

* Thu Aug 09 2018 tv <tv> 2.31-1.mga7
+ Revision: 1250673
- emit perl-base requires for new 32bit perl path

* Thu Aug 09 2018 tv <tv> 2.30-1.mga7
+ Revision: 1250662
- emit perl-base requires for new perl pathes

* Sun Aug 05 2018 wally <wally> 2.29-1.mga7
+ Revision: 1247930
- new version 2.29:
  - fix python bytecompile which has been broken since rpm 4.14.2-rc1

* Sat May 26 2018 wally <wally> 2.28-1.mga7
+ Revision: 1232296
- add -fasynchronous-unwind-tables to default optflags for x86_64 and aarch64 (%%ix86 has it already)

* Sun Apr 29 2018 wally <wally> 2.27-3.mga7
+ Revision: 1223612
- add aarch64 to %%mono_arches

* Sat Apr 21 2018 wally <wally> 2.27-2.mga7
+ Revision: 1220690
- sync gi-find-deps.sh with openSUSE and drop unneeded patches

* Thu Mar 22 2018 wally <wally> 2.27-1.mga7
+ Revision: 1211308
- 2.27: add aarch64 config

* Sun Mar 04 2018 wally <wally> 2.26-2.mga7
+ Revision: 1206465
- add macros.valgrind-srpm from redhat-rpm-config

* Thu Jan 25 2018 tv <tv> 2.26-1.mga7
+ Revision: 1196889
- define %%_pkgdocdir (mga#22444)
- BR ocaml-srpm-macros

* Mon Sep 11 2017 ngompa <ngompa> 2.25-2.mga7
+ Revision: 1152660
- Remove unused overrides

* Mon Aug 07 2017 ngompa <ngompa> 2.25-1.mga7
+ Revision: 1138205
- Remove pythoneggs.py in favor of using upstreamed pythondistdeps.py

* Fri Aug 04 2017 tv <tv> 2.24-3.mga7
+ Revision: 1134669
- submit again

* Thu Aug 03 2017 tv <tv> 2.24-2.mga7
+ Revision: 1134369
- requires gdb for gdb-add-index

* Thu Aug 03 2017 tv <tv> 2.24-1.mga7
+ Revision: 1134298
- drop now useless brp-java-repack-jars
- generate .gdb_index sections by default
- move _debuginfo_subpackages and _debugsource_packages from rpm

* Mon Jul 31 2017 ngompa <ngompa> 2.23-1.mga7
+ Revision: 1132929
- Update to 2.23

* Thu Jul 27 2017 akien <akien> 2.21-3.mga7
+ Revision: 1131545
- Require rust-srpm-macros for rust packaging

* Wed Jul 26 2017 tv <tv> 2.21-2.mga7
+ Revision: 1131308
- disable debugsources by default

* Wed Jul 26 2017 tv <tv> 2.21-1.mga7
+ Revision: 1131302
- support split debugsources in our macros

* Fri Jan 06 2017 wally <wally> 2.20-9.mga6
+ Revision: 1080326
- revert git-core requires for BS chroots

* Fri Jan 06 2017 wally <wally> 2.20-8.mga6
+ Revision: 1080316
- pull git-core to BS chroots to be able to use %%autosetup -S git OOTB

* Fri Dec 30 2016 wally <wally> 2.20-7.mga6
+ Revision: 1078663
- pull cmake-rpm-macros to BS to generate cmake() provides

* Mon Sep 26 2016 tv <tv> 2.20-6.mga6
+ Revision: 1056760
- patch 6: fix generating typelib() requires with gobject-introspection-1.50.0 (g-ir-dep-tool -> g-ir-inspect) (mga#19454)

* Mon Sep 19 2016 tv <tv> 2.20-5.mga6
+ Revision: 1054157
- output typelib() provides for files in /usr/lib64/girepository-1.0/

* Mon Sep 19 2016 tv <tv> 2.20-4.mga6
+ Revision: 1054104
- output typelib() provides for files in /usr/share/gir-1.0 too

* Wed May 18 2016 tv <tv> 2.20-3.mga6
+ Revision: 1016746
- patch 2: prevent emitting bogus requires such as in sugar

* Wed May 18 2016 tv <tv> 2.20-2.mga6
+ Revision: 1016719
- rediff gobjectintrospection.attr patch
- resync gobjectintrospection.attr with SuSe (now matching *.so too)
- resync gi-find-deps.sh with SuSe

* Wed May 04 2016 ngompa <ngompa> 2.20-1.mga6
+ Revision: 1009305
- Update to 2.20

* Tue Apr 26 2016 tv <tv> 2.19-2.mga6
+ Revision: 1006695
- requires python-srpm-macros

* Tue Apr 12 2016 pterjan <pterjan> 2.19-1.mga6
+ Revision: 1000755
- Use rtp's solution to build for armv5tl on armv5tl distro

* Tue Apr 12 2016 pterjan <pterjan> 2.18-1.mga6
+ Revision: 1000678
- add config for armv7hl
- don't append %%ldflags to  forcibly

* Sun Jan 17 2016 wally <wally> 2.17-5.mga6
+ Revision: 925084
- fix typelib() requires generation after changes in file cmd output for python scripts

* Sun Dec 27 2015 neoclust <neoclust> 2.17-4.mga6
+ Revision: 916152
- Move cmake.prov into cmake package

* Sun Dec 27 2015 wally <wally> 2.17-3.mga6
+ Revision: 916023
- move cmake.attr and cmake.prov from cmake to rpm-mageia-setup-build to allow generating cmake() provides also when cmake is not installed

* Wed Dec 02 2015 tv <tv> 2.17-2.mga6
+ Revision: 907612
- add macros.mono-srpm from redhat-rpm-config.

* Sun Nov 15 2015 tv <tv> 2.17-1.mga6
+ Revision: 903456
- drop old tarballs
+ pterjan <pterjan>
- Move rubygem build macros to rubygem package

* Sat Nov 07 2015 ngompa <ngompa> 2.16-1.mga6
+ Revision: 898388
- Update to 2.16 and use revised %%mkrel

* Sat Oct 24 2015 tv <tv> 2.15-2.mga6
+ Revision: 894920
- reenable StrongerHashes

* Sat Oct 24 2015 pterjan <pterjan> 2.15-1.mga6
+ Revision: 894798
- Update gem_install

* Wed Oct 21 2015 pterjan <pterjan> 2.14-1.mga6
+ Revision: 893416
- do not remove buildroot in %%install if install is disabled
  (to make rpmbuild --without install actually useful)
- make python dependency extractor much faster

* Tue Sep 29 2015 tv <tv> 2.13-2.mga6
+ Revision: 885100
- fix build with rpm-4.13 (debuginfo package is empty)

* Mon Aug 24 2015 tv <tv> 2.13-1.mga6
+ Revision: 869028
- kill python macros that are already defined in rpm
- kill unused python macros (py_compile, py_requires)

* Sun Jul 12 2015 cjw <cjw> 2.12-1.mga6
+ Revision: 853395
- do not add -fPIC to x86-64 optflags, this option should only be used for shared libraries

* Fri Jul 03 2015 tv <tv> 2.11-1.mga6
+ Revision: 849642
- deprecate %%makeinstall_std and advertize upstream %%make_install instead
- kill %%old_makeinstall (use upstream %%makeinstall instead)

* Sun Jun 28 2015 tv <tv> 2.10-1.mga6
+ Revision: 847156
- stop emitting perlapi-<version> provides
  now that nothing requires it

* Wed Jun 24 2015 tv <tv> 2.9-1.mga6
+ Revision: 842504
- stop emitting perlapi-<version> requires
- patch 2: temporary revert change file digests hashing algorithm to SHA-256

* Sun Jun 21 2015 tv <tv> 2.8-1.mga6
+ Revision: 837783
- change file digests hashing algorithm to SHA-256
- kill obsolete %%defaultbuildroot
- kill old %%__find_(provides|requires)
- kill redondant/unmainted macro (mga#4927)
- kill unused kmod.* files

* Sun Oct 26 2014 tv <tv> 2.7-1.mga5
+ Revision: 793402
- add support for limiting parallel builds by defining
  %%_smp_ncpus_max in spec file for packages needing it
- drop merged patch 2
- add a warning about patches
- add comments about patches on suse stuff

* Fri Oct 24 2014 tmb <tmb> 2.6-5.mga5
+ Revision: 792995
- add support for limiting parallel builds by defining
  %%_smp_ncpus_max in spec file for packages needing it

* Sun Oct 19 2014 cjw <cjw> 2.6-4.mga5
+ Revision: 791756
- gobjectintrospection.attr: match python scripts without .py file extension

* Sun Oct 19 2014 wally <wally> 2.6-3.mga5
+ Revision: 791729
- add patch to
  * find typelib() requires also from .gresource files
  * fix exclude path for typelib() requires

* Wed Oct 15 2014 umeabot <umeabot> 2.6-2.mga5
+ Revision: 740065
- Second Mageia 5 Mass Rebuild

* Tue Oct 14 2014 pterjan <pterjan> 2.6-1.mga5
+ Revision: 738720
- Fix pythonegg dependencies generation

* Wed Oct 01 2014 tv <tv> 2.5-1.mga5
+ Revision: 733887
- do not emit PHP requires for package's own files

* Fri Sep 26 2014 tv <tv> 2.4-1.mga5
+ Revision: 724836
- emit pythonegg requires/provides back
- remove kmod.* from git (now SRPMS sources)
- remove dwz.macros from git (now SRPMS sources)
- remove now useless g-ir-extract-deps

* Thu Sep 25 2014 wally <wally> 2.3-6.mga5
+ Revision: 724625
- redo P0 (drop cache file and move $GI_TYPELIB_PATH parts to typelib_requires function in gi-find-deps.sh to speed up build)

* Thu Sep 25 2014 tv <tv> 2.3-5.mga5
+ Revision: 724579
- patch 0: speedup slow gi-find-deps.sh when there's lot of matching files

* Thu Sep 25 2014 tv <tv> 2.3-4.mga5
+ Revision: 724532
- set GI_TYPELIB_PATH when generating typelib() requires

* Tue Sep 23 2014 tv <tv> 2.3-3.mga5
+ Revision: 720936
- require gobject-introspection for g-ir-dep-tool
+ wally <wally>
- sync gi-find-deps.sh more with Suse to get .typelib requires to work

* Mon Sep 22 2014 tv <tv> 2.3-2.mga5
+ Revision: 719169
- fix kmod.attr path for kernels

* Fri Sep 19 2014 pterjan <pterjan> 2.3-1.mga5
+ Revision: 695909
- 2.3 (generate devel dependencies for gcc libs)
+ tv <tv>
- move kmod.{attr,prov} as sources
- use %%_rpmconfigdir consistently
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Mon Sep 15 2014 tmb <tmb> 2.2-2.mga5
+ Revision: 676812
- require pcre instead of non-existant pcre-tools

* Mon Sep 15 2014 tmb <tmb> 2.2-1.mga5
+ Revision: 676792
- make rpm-mageia-setup-build require pcre-tools and file
- fix matching META files
- retrieve file name from stdin
+ tv <tv>
- actually package php.attr
- convert kmod provides to internal generator
- convert perl requires from meta to internal generator
- use rpmdeps to generate any "normal" dependencies

* Sun Sep 14 2014 lmenut <lmenut> 2.0-4.mga5
+ Revision: 675238
- fix conflicts

* Sun Sep 14 2014 tmb <tmb> 2.0-3.mga5
+ Revision: 675230
- rebuild with fixed bash

* Sun Sep 14 2014 tv <tv> 2.0-2.mga5
+ Revision: 675180
- move gi-find-deps.sh here so that gobject-introspection can have auto provs

* Fri Sep 12 2014 tv <tv> 2.0-1.mga5
+ Revision: 674900
- 2.0 aka "the next one who forks a script will be shoot. twice"
- convert devel(foo) deps to internal generator
- convert multiarch deps to internal generator
- convert "perlapi" deps to internal generator
- convert perl-base deps to internal generator
- convert PHP deps to internal generator
- drop gstreamer/haskell/ruby/typelib deps generators
  we backported the needed .(attr|prov|req) files from FC/SuSe in other packages
- drop most of the script-based dependency generation bits
- drop some long dead scripts
- use internal dependency generator instead of "external generator"
  (like all other distros) which is way much faster :-)
  See:
  o http://www.rpm.org/wiki/PackagerDocs/DependencyGenerator
  o http://laiskiainen.org/blog/?p=35
  side effect: we now output lowercase perl provides/requires (eg: "perl(urpm)")
- use upstream pkgconfigdeps.sh as we only have more checks because we were
  still using the external generator

* Mon May 26 2014 wally <wally> 1.198-1.mga5
+ Revision: 626853
- gi-find-deps.sh: improve sed magic to handle special sugar typelib requires

* Sat Dec 28 2013 pterjan <pterjan> 1.197-1.mga4
+ Revision: 561711
- Fix gem automated dependancies

* Fri Dec 27 2013 pterjan <pterjan> 1.196-1.mga4
+ Revision: 560992
- Use correct macro for gems dir now that rubygems moved

* Tue Dec 24 2013 pterjan <pterjan> 1.195-1.mga4
+ Revision: 560546
- Fix mistake in previous version

* Tue Dec 24 2013 pterjan <pterjan> 1.194-1.mga4
+ Revision: 560319
- Only install gem .so from paths in require_paths

* Wed Dec 18 2013 pterjan <pterjan> 1.193-1.mga4
+ Revision: 558577
- Improve binary gems handling and get more compatible with Fedora

* Tue Oct 22 2013 umeabot <umeabot> 1.192-2.mga4
+ Revision: 545433
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 pterjan <pterjan> 1.192-1.mga4
+ Revision: 501266
- Switch pythonegg dependencies to versioned style
- Add -O to %%make macro

* Mon Oct 14 2013 pterjan <pterjan> 1.191-1.mga4
+ Revision: 497607
- Generate different provides for python2 and python3

* Mon Sep 30 2013 dmorgan <dmorgan> 1.190-2.mga4
+ Revision: 489553
- Try to fix osgi() provides/requires

* Sat Sep 28 2013 fwang <fwang> 1.190-1.mga4
+ Revision: 488322
- 1.190: add switch -d to gem_install to move headers into vendorarchdir

* Wed Sep 25 2013 philippem <philippem> 1.189-1.mga4
+ Revision: 486361
- Set valid macros names for Python byte compilation

* Wed Sep 25 2013 philippem <philippem> 1.188-1.mga4
+ Revision: 486292
- improve macros for Python byte compilation

* Tue Sep 24 2013 philippem <philippem> 1.187-1.mga4
+ Revision: 485456
- add macros for Python byte compilation

* Fri Sep 20 2013 pterjan <pterjan> 1.186-2.mga4
+ Revision: 481799
- Use the correct tarball :(

* Fri Sep 20 2013 pterjan <pterjan> 1.186-1.mga4
+ Revision: 481787
- Support gems with .so under ext and not installed in lib

* Fri Sep 20 2013 pterjan <pterjan> 1.185-1.mga4
+ Revision: 481762
- Fix typo in previous version :(

* Fri Sep 20 2013 pterjan <pterjan> 1.184-1.mga4
+ Revision: 481747
- Support empty gems

* Fri Sep 20 2013 pterjan <pterjan> 1.183-1.mga4
+ Revision: 481728
- Handle another git ls-files syntax in gem_setup
- Fix dependency generation when ruby_version is empty

* Tue Sep 10 2013 pterjan <pterjan> 1.182-1.mga4
+ Revision: 477387
- Fix install of gems with several .so

* Tue Sep 10 2013 pterjan <pterjan> 1.181-1.mga4
+ Revision: 477287
- Support gems with the .so in a subdirectory

* Tue Sep 10 2013 pterjan <pterjan> 1.180-1.mga4
+ Revision: 477258
- Create a gem_setup macro fixing most common problems

* Sun Sep 08 2013 pterjan <pterjan> 1.179-1.mga4
+ Revision: 476420
- Remove extra space in __ruby_module_name when oname is not defined

* Thu Aug 15 2013 fwang <fwang> 1.178-1.mga4
+ Revision: 466706
- rely on plain gem command to build and install gems

* Thu Aug 15 2013 fwang <fwang> 1.177-2.mga4
+ Revision: 466689
- refresh updated tarball

* Thu Aug 15 2013 fwang <fwang> 1.177-1.mga4
+ Revision: 466683
- make it compat with rubygems 2.0

* Wed Jul 31 2013 wally <wally> 1.176-1.mga4
+ Revision: 461847
- gi-find-deps.sh: sync more with SUSE to find typelib requires from Python scripts without .py extension (mga#10863)

* Mon Jul 29 2013 wally <wally> 1.175-1.mga4
+ Revision: 460609
- gi-find-deps.sh: sync 'find javascript requires' code with SUSE to find versioned requires

* Sat Jul 06 2013 wally <wally> 1.174-1.mga4
+ Revision: 450780
- gi-find-deps.sh: handle 'gi.require_version("Gtk", "3.0")' type requires in .py files (from SUSE)

* Fri Jul 05 2013 dmorgan <dmorgan> 1.173-1.mga4
+ Revision: 450289
- Add auto requires for osgi() mvn()

* Tue Jun 04 2013 colin <colin> 1.172-1.mga4
+ Revision: 437170
- New version 1.172
  o Add pkgconfig package requires for private requires

* Sat Apr 06 2013 luigiwalser <luigiwalser> 1.171-1.mga3
+ Revision: 408556
- properly fix mga #3697 in find-lang.pl (only exclude man directories)
- own man pages that have a dot in their name (find-lang.pl regexp bug)
+ lmenut <lmenut>
- fix regression introduced in 1.168:
  all directories found by find-lang are not owned by packages
  when --with-man is used (mga #3697c10)

* Sun Mar 24 2013 colin <colin> 1.169-1.mga3
+ Revision: 404799
- New version: 1.169
- Add version macros for systemd/rpm-helper to ease distro upgrades

* Sun Mar 17 2013 lmenut <lmenut> 1.168-1.mga3
+ Revision: 403530
- New version : 1.168
  fix find-lang.pl : do not own man lang directories with --with-man
  (patch from tv, mga #3697 & #9055)
+ fwang <fwang>
- update rpm group
- fix bug#8757, gi-find-deps.sh incorrectly match 'imports.github'

* Mon Jan 14 2013 umeabot <umeabot> 1.166-2.mga3
+ Revision: 380455
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 10 2013 boklm <boklm> 1.166-1.mga3
+ Revision: 344741
- Add script to generate tarball
+ rtp <rtp>
- update optflags and fix dwz settings on arm

* Mon Dec 31 2012 tmb <tmb> 1.165-1.mga3
+ Revision: 336686
- set libexec dir to /usr/libexec

* Sun Nov 25 2012 colin <colin> 1.164-1.mga3
+ Revision: 321720
- New version: 1.164
- Add some macros for udev rules and tmpfiles snippets

* Fri Nov 23 2012 blino <blino> 1.163-1.mga3
+ Revision: 321136
- 1.163
- modify arch_tagged macro to use ()(64bit) instead of (lib64), to be
  compatible with the mark64 provides generated by find-provides

* Fri Nov 02 2012 fwang <fwang> 1.162-1.mga3
+ Revision: 312393
- new version 1.162

* Wed Oct 24 2012 tv <tv> 1.161-1.mga3
+ Revision: 309549
- set LC_ALL=C in find-{provides,requires} (mga#7883)

* Wed Sep 12 2012 fwang <fwang> 1.160-1.mga3
+ Revision: 292616
- 1.160: merge rubygems.rb from Mandriva, so that it works with ruby 1.9.x

* Mon Sep 10 2012 shlomif <shlomif> 1.159-1.mga3
+ Revision: 291994
- New version 1.159, with fix to the gem_helper problem.

* Sat Sep 08 2012 fwang <fwang> 1.158-1.mga3
+ Revision: 289992
- 1.158: only enable rubygems when /usr/bin/ruby is found

* Fri Aug 24 2012 tv <tv> 1.157-1.mga3
+ Revision: 283502
- find-provides: fix pok's perlapi auto provides

* Tue Aug 21 2012 tv <tv> 1.156-1.mga3
+ Revision: 282990
- find-provides: ignore fontconfig.prov exit code (mga#7078)

* Fri Aug 03 2012 tv <tv> 1.155-1.mga3
+ Revision: 278305
- actually require dwz

* Thu Aug 02 2012 tv <tv> 1.155-0.1.mga3
+ Revision: 277874
- drop very old rpmbuild aliases on rpm which warns about being deprecated for
  quite a long time
- enable including mini debuginfo in binaries

* Tue Jul 31 2012 tv <tv> 1.154-1.mga3
+ Revision: 276799
- drop unused brp-compress (obsoleted by spec-helper 4 years ago)
- use upstream find-debuginfo.sh as we merged our changes back into rpm package

* Tue Jul 31 2012 tv <tv> 1.153-1.mga3
+ Revision: 276735
- shrunk debug packages through using dwz
  (https://fedoraproject.org/wiki/Features/DwarfCompressor)

* Fri Jul 27 2012 tv <tv> 1.152-1.mga3
+ Revision: 275050
- require dwz
- add support for mini debug packages
  (https://fedoraproject.org/wiki/Features/MiniDebugInfo)
- document Mageia divergences with upstream
- fix typo that breaks emiting maven provides
- generate a perlapi-<version> provide when libperl.so is found
  (inspirated from mdv (pok))
- sync brp-compress with upstream rpm.org:
  o add *.xz and *.lzma recompress support
  o avoid some unnecessary command invocations in scripts
  o make sure brp-compress doesn't go interactive in corner cases
- sync find-debuginfo.sh with upstream rpm.org:
  o add -r flag to find-debuginfo.sh to invoke eu-strip --reloc-debug-sections
    (Mark Wielaard, 2011-05-25)
  o create GDB index from find-debuginfo if possible (Tom Tromey, RhBug:617166)
  o drop useless rpm5 bits (less divergence with upstream)
  o generate debug symlinks for all filenames sharing a build-id (RhBug:641377)
  o fix behavior on cross-directory hardlinks (RhBug:618426)
- kill unused find-provides.perl.in
- prevent RPM_BUILD_ROOT to break brp-* scripts if it contains spaces
  (rpm.org#843)
- revert %%_libexecdir change in 1.151
- use upstream brp-strip* as we provided older versions of upstream

* Thu Jul 26 2012 tv <tv> 1.151-1.mga3
+ Revision: 274628
- fix %%_libexecdir that changed to %%_libdir when mga forked mdv
  (when we merged manbo stuff)
- install g-ir-extract-deps in the right place
- perl.prov: do not keep lower case provides since we do not
  emit lower case requires anyway
- switch from lzma to xz payload by default (like FC & mdv)
  (supported since 2008)

* Thu Jul 26 2012 tv <tv> 1.150-1.mga3
+ Revision: 274530
- build with -fPIC on x86_64 too (pok, mdv)

* Wed Jul 25 2012 tv <tv> 1.149.1-1.mga3
+ Revision: 274313
- merged patches from pkg repository into SVN

* Wed Jul 25 2012 tv <tv> 1.148-1.mga3
+ Revision: 274302
- drop automatically generated dependencies on interpreters we either don't
  need dependencies on or that we have other dedicated dependency generators
  for making them duplicate, reducing ~5K packages' dependencies at
  next rebuild. (Per Oyvind, mdv)
- drop automatically generated rtld(GNU_HASH) dependencies, it's been provided
  by glibc for five years now and can safely be assumed that there's no longer
  any need for it, reducing ~8K packages' dependency on it during next rebuild.
  (Per Oyvind, mdv)
- "resolve" /bin/env foo interpreter to actual path, rather than generating
  dependencies on coreutils, should trim off ~800 dependencies more
- perl.prov: sync with upstream rpm.org:
  o avoid emitting empty perl() module deps
  o filter out incorrect perl(main) provides (rh#177960)
  o fix perl version provide for packages defined in multiple blocks (#rhbz214496)
  o make perl.{req,prov} warn about unreadable files
  o skip new-fangled head[34] while gerenerating deps (#118243)
  o skip over =for ... perlpod construct (RhBug:477516)
- use upstream fonconfig.prov as we had exactly the same file

* Tue Jul 24 2012 colin <colin> 1.147-12.mga3
+ Revision: 274043
- Update location of the %%_unitdir macro post-usrmove

* Sun Jul 01 2012 dmorgan <dmorgan> 1.147-11.mga3
+ Revision: 266385
- Fix use of maven and osgi prov script
+ tv <tv>
- fix upgrade from mdv

* Wed Jun 27 2012 kamil <kamil> 1.147-9.mga3
+ Revision: 264252
-add P8: fix-rename-macro.patch (mga#4345)

* Sat Apr 28 2012 tmb <tmb> 1.147-8.mga2
+ Revision: 233577
- disable rpm-helper autoreq script as it breaks more than it fixes

* Fri Apr 27 2012 tmb <tmb> 1.147-7.mga2
+ Revision: 233483
- add autoreq script to add versioned rpm-helper requires for systemd (guillomovitch/tv/tmb)

* Thu Feb 16 2012 tmb <tmb> 1.147-6.mga2
+ Revision: 209755
- have kmod.prov handle .xz compressed modules as well

* Mon Feb 13 2012 dmorgan <dmorgan> 1.147-5.mga2
+ Revision: 208317
- Better handling of osgi.prov

* Thu Jan 26 2012 blino <blino> 1.147-4.mga2
+ Revision: 201807
- require rpmlint-mageia-policy, as discussed on "[Mageia-dev] rpmlint"
  thread, and as per suggestion of pterjan

* Sat Dec 31 2011 dmorgan <dmorgan> 1.147-3.mga2
+ Revision: 189248
- Only catch maven pom files ( mga #3963)

* Wed Dec 28 2011 dmorgan <dmorgan> 1.147-2.mga2
+ Revision: 188289
- Add P2: Use new osgi/maven.prov files from jpackages-utils
  Add P3: Use upstream desktop-file.prov as our is identical
- Remove P0: reverted in svn because breaks deps generator

* Tue Dec 27 2011 anssi <anssi> 1.147-1.mga2
+ Revision: 188160
- 1.147
  o add support for $EXCLUDE_FROM_FULL_STRIP regexp which makes
    find-debuginfo.sh only strip debugging symbols from the matched files
    (from Mandriva).

* Mon Dec 26 2011 dmorgan <dmorgan> 1.145-3.mga2
+ Revision: 187657
- Disable internal deps generator

* Sun Dec 25 2011 dmorgan <dmorgan> 1.145-2.mga2
+ Revision: 187548
- Add P1: Fix build with rpm 4.9
- Revert to  version 1.145
  Add patch enabling dep generator
- Use new source
- Remove old source
- Enable new internal dep generator ( needed for java packages)

* Tue Nov 08 2011 jquelin <jquelin> 1.145-1.mga2
+ Revision: 165314
- update to 1.145

* Mon Sep 19 2011 fwang <fwang> 1.144-1.mga2
+ Revision: 145263
- new version 1.144
+ misc <misc>
- do not hardcode the name of the distribution
- fix Requires, and add some various comments
- do not keep old directive to use /etc/rpm/platform, as this is unused on
  the regular rpm version
- remove useless conflicts
- remove others old obsoletes
- clean the spec, remove old directives
- remove old Conflict/Obsoletes, as we are no longer supporting upgrade from Mandriva
- remove temporary Provides ( nothing requires perl-suid )

* Mon Aug 29 2011 jquelin <jquelin> 1.142-1.mga2
+ Revision: 136029
- update to 1.142
+ fwang <fwang>
- push python-gi req for python introspection callings
- 1.140: push python-gi req for python introspection callings

* Fri Jul 15 2011 cjw <cjw> 1.139-1.mga2
+ Revision: 124427
- 1.139: gobject introspection requires: do not emit typelib(GOBJ) when
         no deps are listed in a typelib

* Thu Jul 07 2011 cjw <cjw> 1.138-1.mga2
+ Revision: 119922
- 1.138: gobject introspection dependencies fix for python:
         ignore whitespace in the comma-separated lists

* Thu Jul 07 2011 boklm <boklm> 1.137-1.mga2
+ Revision: 119882
- version 1.137 from cjw: extract gobject introspection typelib interdependencies using a helper program

* Wed Jul 06 2011 boklm <boklm> 1.136-1.mga2
+ Revision: 119525
- version 1.136

* Wed Jul 06 2011 boklm <boklm> 1.135-1.mga2
+ Revision: 119453
- version 1.135

* Mon May 30 2011 pterjan <pterjan> 1.133-1.mga1
+ Revision: 100758
- Default section to core, useful for local builds

* Mon May 30 2011 pterjan <pterjan> 1.132-1.mga1.
+ Revision: 100750
- do not append .%%distro_section if section is core

* Fri May 20 2011 pterjan <pterjan> 1.131-1.mga1
+ Revision: 99853
- Update to 1.131 with new mkrel

* Fri May 06 2011 boklm <boklm> 1.130-1.mga1
+ Revision: 95456
- version 1.130

* Thu Apr 28 2011 boklm <boklm> 1.127-1.mga1
+ Revision: 93318
- version 1.127

* Wed Mar 23 2011 boklm <boklm> 1.126-1.mga1
+ Revision: 76098
- version 1.126 to fix #497

* Wed Mar 16 2011 rtp <rtp> 1.124-1.mga1
+ Revision: 72723
- Version 1.124: fix _host macro

* Sun Mar 13 2011 boklm <boklm> 1.123-1.mga1
+ Revision: 70792
- version 1.123: add fontconfig.prov provides script

* Fri Mar 04 2011 boklm <boklm> 1.122-1.mga1
+ Revision: 63866
- version 1.122

* Thu Mar 03 2011 tmb <tmb> 1.120-1.mga1
+ Revision: 63420
- kmod.prov: convert special chars [,],:,- to _ when generating
  kernel module version provides (needed with rpm-4.8.1)

* Wed Mar 02 2011 jquelin <jquelin> 1.119-1.mga1
+ Revision: 62625
- update to 1.119

* Mon Feb 28 2011 tmb <tmb> 1.118-2.mga1
+ Revision: 61576
- drop /usr/lib/rpm/manbo symlink as rpm is now fixed

* Sat Feb 26 2011 jquelin <jquelin> 1.118-1.mga1
+ Revision: 60350
- update to 1.118

* Sun Feb 20 2011 ahmad <ahmad> 1.117-1.mga1
+ Revision: 55071
- new version 1.117
  o merge svn rev. 271797 from Mandriva to make the python eggs auto-requires
    always lowercase

* Sun Feb 06 2011 tmb <tmb> 1.116-1.mga1
+ Revision: 47647
- new version 1.116
  - merge rpmrc from rpm-manbo-setup
  - merge manbo.macros from rpm-manbo-setup
  - merge manbo-build.macros from rpm-manbo-setup
  - merge under/overlinking scripts from rpm-manbo-setup
  - merge rpm -b deprecated warning scripts from rpm-manbo-setup
- obsolete rpm-manbo-setup(-build) to get a clean upgrade
- add /usr/lib/rpm/manbo symlink pointing to /usr/lib/rpm/mageia
  in order to allow upgrade without breaking current rpm and BS

* Tue Jan 25 2011 shikamaru <shikamaru> 1.115-12.mga1
+ Revision: 39575
- fix dependencies in rubygems.rb (only include runtime dependencies)

* Thu Jan 20 2011 blino <blino> 1.115-11.mga1
+ Revision: 25078
- hardcode _real_vendor
- use _real_vendor macro
- revert rpm-manbo-setup obsoletes since it is not merged

* Wed Jan 19 2011 tmb <tmb> 1.115-9.mga1
+ Revision: 24937
- hardcode distro name to mageia to get rid of rpm-manbo-setup-*
- drop requirements on rpm-manbo-setup-*
- obsolete rpm-manbo-setup-*

* Tue Jan 18 2011 blino <blino> 1.115-8.mga1
+ Revision: 21934
- add hackish perl-suid provides to ease perl-5.12 transition

* Mon Jan 17 2011 blino <blino> 1.115-7.mga1
+ Revision: 20662
- remove python abi hack

* Thu Jan 13 2011 pterjan <pterjan> 1.115-6.mga1
+ Revision: 12442
- Bump release
+ blino <blino>
- add a FIXME note
- temporarily add a python(abi) provide while python is not upgraded

* Mon Jan 10 2011 blino <blino> 1.115-4.mga1
+ Revision: 4926
- rebuild
- provide rpm-mandriva-setup to ease transition

* Sun Jan 09 2011 blino <blino> 1.115-2.mga1
+ Revision: 3793
- obsolete rpm-mandriva-setup package

* Sun Jan 09 2011 blino <blino> 1.115-1.mga1
+ Revision: 3489
- remove old workaround
- update comment in rpm-mode for emacs
- use distro_release macro
- update hardcoded distsuffix
- use rpm-mageia-setup tarball
- put lowercased distro name in a macro
- update the distribution name macro
- require mageia-release
- remove old macros and version checks
- rename spec file
- rename as rpm-mageia-setup
- imported package rpm-mandriva-setup

